{# templates/master_slave/default_multiprocessing.j2 #}
# Esse fallback pode delegar para a função gerada, ou repetir a estrutura acima adaptada para loop.
# Mantendo simples, você pode só documentar que 'function_*' é o suporte atual.
